Struct gns3::GNS3LinkEndpoint[][src]

pub struct GNS3LinkEndpoint {
    pub node_id: String,
    pub adapter_number: u32,
    pub port_number: u32,
}

Endpoint of a link

Fields

node_id: String

ID of the node for which the link is configured

adapter_number: u32

adapter number

port_number: u32

port number

Implementations

impl GNS3LinkEndpoint[src]

pub fn from_node(node: &GNS3Node, iface_id: usize) -> Self[src]

Create a link endpoint from a node, and the index of the link.